@@ -5,12 +5,12 @@ use warnings;
 use parent qw/Plack::Middleware/;
 use Plack::Util;
 use Time::HiRes qw/gettimeofday/;
-use Plack::Util::Accessor qw/response_time combined error_only long_response_time logger/;
+use Plack::Util::Accessor qw/response_time combined ltsv error_only long_response_time logger/;
 use POSIX qw//;
 use Time::Local qw//;
 use HTTP::Status qw//;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 ## copy from Plack::Middleware::AccessLog
 my $tzoffset = POSIX::strftime("%z", localtime);
@@ -79,17 +79,35 @@ sub log_line {
     my @lt = localtime($t0->[0]);
     my $t = sprintf '%02d/%s/%04d:%02d:%02d:%02d %s', $lt[3], $abbr[$lt[4]], $lt[5]+1900, 
         $lt[2], $lt[1], $lt[0], $tzoffset;
-    my $log_line =  _string($env->{REMOTE_ADDR}) . " "
-        . '- '
+    my $log_line;
+
+    if ( $self->{ltsv} ) {
+        #host:%h user:%u time:%t req:%r status:%>s size:%b referer:%{Referer}i ua:%{User-agent}i
+        $log_line =
+            "host:" . _string($env->{REMOTE_ADDR}) . "\t"
+          . "user:" . _string($env->{REMOTE_USER}) . "\t"
+          . "time:[" .$t . "]\t"
+          . "req:" . _safe($env->{REQUEST_METHOD} . " " . $env->{REQUEST_URI} . " " . $env->{SERVER_PROTOCOL}) . "\t"
+          . "status:" . $res->[0] . "\t"
+          . "size:" . (defined $length ? "$length" : '-') . "\t"
+          . "referer:" . _string($env->{HTTP_REFERER}) . "\t"
+          . "ua:" .  _string($env->{HTTP_USER_AGENT}) 
+          . ( $self->{response_time} ? "\ttaken:$elapsed" : '')
+          . "\n";
+    }
+    else {
+        $log_line =  _string($env->{REMOTE_ADDR}) . " "
+            . '- '
             . _string($env->{REMOTE_USER}) . " "
-                . q![!. $t . q!] !
-                . _safe(q!"! . $env->{REQUEST_METHOD} . " " . $env->{REQUEST_URI} . " " . $env->{SERVER_PROTOCOL} . q!" !)
-                . $res->[0] . " "
-                . (defined $length ? "$length" : '-')
-                . ($self->{combined} ? q! "! . _string($env->{HTTP_REFERER}) . q!" ! : '')
-                . ($self->{combined} ? q!"! . _string($env->{HTTP_USER_AGENT}) . q!"! : '')
-                . ($self->{response_time} ? " $elapsed" : '')
-                . "\n";
+            . q![!. $t . q!] !
+            . _safe(q!"! . $env->{REQUEST_METHOD} . " " . $env->{REQUEST_URI} . " " . $env->{SERVER_PROTOCOL} . q!" !)
+            . $res->[0] . " "
+            . (defined $length ? "$length" : '-')
+            . ($self->{combined} ? q! "! . _string($env->{HTTP_REFERER}) . q!" ! : '')
+            . ($self->{combined} ? q!"! . _string($env->{HTTP_USER_AGENT}) . q!"! : '')
+            . ($self->{response_time} ? " $elapsed" : '')
+            . "\n";
+    }
 
     if ( ! $self->{logger} ) {
         $env->{'psgi.errors'}->print($log_line);
@@ -135,13 +153,13 @@ Plack::Middleware::AxsLog - Fixed format but Fast AccessLog Middleware
 =head1 DESCRIPTION
 
 Alternative implementation of Plack::Middleware::AccessLog.
-Only supports combined and common format, but 3x-4x faster than Plack::Middleware::AccessLog 
+Only supports combined, common and ltsv format, but 3x-4x faster than Plack::Middleware::AccessLog 
 in micro benchmarking.
 AxsLog also supports filter logs by response_time and status code.
 
 =head1 LOG FORMAT
 
-AxsLog supports combined and common format. And adds elapsed time in microseconds to last of log line
+AxsLog supports combined, common and ltsv format. And adds elapsed time in microseconds to last of log line
 
 =over 4
 
@@ -155,6 +173,13 @@ AxsLog supports combined and common format. And adds elapsed time in microsecond
   %h %l %u %t \"%r\" %>s %b %D 
   => 127.0.0.1 - - [23/Aug/2012:00:52:15 +0900] "GET / HTTP/1.0" 200 645 10941
 
+=item LTSV (Labeled Tab-separated Values)
+
+  host:%h<TAB>user:%u<TAB>time:%t<TAB>req:%r<TAB>status:%>s<TAB>size:%b<TAB>referer:%{Referer}i<TAB>ua:%{User-agent}i<TAB>taken:%D
+  => host:127.0.0.1<TAB>user:-<TAB>time:[23/Aug/2012:00:52:15 +0900]<TAB>req:GET / HTTP/1.1<TAB>status:200<TAB>size:645<TAB>"referer:-<TAB>ua:Mozilla/5.0 (Macintosh; Intel Mac OS X 10_6_8) AppleWebKit/537.1 (KHTML, like Gecko) Chrome/21.0.1180.79 Safari/537.1<TAB>taken:10941
+
+See also L<http://ltsv.org/>
+
 =back
 
 =head1 CONFIGURATION
@@ -165,9 +190,13 @@ AxsLog supports combined and common format. And adds elapsed time in microsecond
 
 log format. if disabled, "common" format used. default: 1 (combined format used)
 
+=item ltsv: Bool
+
+use ltsv log format. default: 0
+
 =item response_time: Bool
 
-Adds time to serve the request. default: 0
+Adds time taken to serve the request. default: 0
 
 =item error_only: Bool
 
@@ -175,7 +204,7 @@ Display logs if response status is error (4xx or 5xx). default: 0
 
 =item long_response_time: Int (microseconds)
 
-Display log if time to serve the request is above long_response_time. default: 0 (all request logged)
+Display log if time taken to serve the request is above long_response_time. default: 0 (all request logged)
 
 =item logger: Coderef
 
